---
title: 토스페이 상점아이디추가 절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 서비스 추가/변경
seo:
  title: 토스페이 상점아이디추가
  description: >-
    토스페이의 상점아이디(사이트코드) 추가절차 안내입니다. 추가 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되며, 상점아이디를
    추가하실 수 있는 경우를 확인하세요.
  keywords:
    - 토스페이
    - 서비스추가/변경
tags:
  - 토스페이
  - 서비스추가/변경
pgCompanies:
  - 토스페이
searchTags:
  - 토스페이 사이트추가
  - 토스페이 사이트 추가
  - 토스페이 서비스 추가
  - 토스페이 서비스추가
  - 토스페이MID추가
  - 토스페이 MID추가
  - 토스페이MID
  - 토스페이 MID
  - 토스페이 상점아이디 추가
  - 토스페이 상점아이디
  - 상점아이디 추가
  - 상점아이디추가
  - 토스간편결제
  - 토스페이
datetime: 2023-11-14T15:00:00.000Z
---

<Callout content="토스페이 상점아이디 추가 절차를 안내해드립니다. 추가되는 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되는 점 참고해주세요." />

<Callout title="포트원 기준 결제대행사 수수료 보러가기↗" />

### **상점아이디 추가 케이스**

<Callout content="포트원 정책에 의하여 기존에 포트원을 통하지 않고 계약된 상점아이디는 포트원 서비스 사용이 불가합니다. 새로운 포트원용 상점아이디를 추가 발급 받으신 후 이용해주시기 바랍니다." title="참고사항" icon="💡" />

- 이미 토스페이와 직접 계약이 되어있다가 포트원으로 연동하고자 하시는 경우
- 새로운 서비스가 추가되는 경우 (=심사를 다시 받아야 하는 경우)
- 기존 서비스와 결제/정산을 분리하고자 하시는 경우
- 심사받은 적 없는 연동방식을 추가하시는 경우 (ex. 일반결제 사용중에 정기결제 추가시)

### **신청방법**

1. [서비스 신청서 다운로드↗](https://docs.google.com/document/d/1-J3iVDKwlDH8M-R41csOr0esUFnrqc8P/edit) 하기

2\. 서비스 신청서 작성 및 구비서류 준비 후 아래로 등기 발송합니다.

- 퀵/택배 등을 통한 배송시, 퀵/택배사의 귀책으로 발생한 서류 반송, 분실, 파손 등에 대하여 일체 책임지지 않으니 등기우편으로 접수하시길 권장드립니다.
  - 받는 사람    ㈜비바리퍼블리카 (우 06236) 서울시 강남구 테헤란로 142, 12층 (역삼동, 아크플레이스)
    토스페이 계약팀 앞
  - 가맹점 가입 및 서류 관련 문의가 있다면 <support-pay@toss.im> 으로 문의 주시기 바랍니다.
